@@ -1,4 +1,5 @@
 from .lambda_api_gateway import LambdaAPIGateway
+import json
 from clearskies.handlers.exceptions import ClientError
 class LambdaInvocation(LambdaAPIGateway):
     def __init__(self, event, context):
@@ -14,3 +15,6 @@ class LambdaInvocation(LambdaAPIGateway):
         if required and not self._event:
             raise ClientError("Request body was not valid JSON")
         return self._event
+
+    def respond(self, body, status_code=200):
+        return body.decode('utf-8') if type(body) == bytes else body
